/* widgets.c generated by valac 0.38.8, the Vala compiler
 * generated from widgets.vala, do not modify */

/*
 Copyright (C) 2009-2014 Christian Dywan <christian@twotoasts.de>
 Copyright (C) 2009-2012 Alexander Butenko <a.butenka@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 See the file COPYING for the full license text.
*/

#include <glib.h>
#include <glib-object.h>
#include "toolbar-editor.h"
#include <gtk/gtk.h>
#include "midori-core.h"
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <gdk/gdk.h>
#include <gobject/gvaluecollector.h>

enum  {
	ADBLOCK_STATUS_ICON_0_PROPERTY,
	ADBLOCK_STATUS_ICON_NUM_PROPERTIES
};
static GParamSpec* adblock_status_icon_properties[ADBLOCK_STATUS_ICON_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _adblock_subscription_manager_unref0(var) ((var == NULL) ? NULL : (var = (adblock_subscription_manager_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block3Data Block3Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _AdblockParamSpecSubscriptionManager AdblockParamSpecSubscriptionManager;

#define ADBLOCK_TYPE_CUSTOM_RULES_EDITOR (adblock_custom_rules_editor_get_type ())
#define ADBLOCK_CUSTOM_RULES_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, AdblockCustomRulesEditor))
#define ADBLOCK_CUSTOM_RULES_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, AdblockCustomRulesEditorClass))
#define ADBLOCK_IS_CUSTOM_RULES_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR))
#define ADBLOCK_IS_CUSTOM_RULES_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR))
#define ADBLOCK_CUSTOM_RULES_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, AdblockCustomRulesEditorClass))

typedef struct _AdblockCustomRulesEditor AdblockCustomRulesEditor;
typedef struct _AdblockCustomRulesEditorClass AdblockCustomRulesEditorClass;
typedef struct _AdblockCustomRulesEditorPrivate AdblockCustomRulesEditorPrivate;
typedef struct _AdblockParamSpecCustomRulesEditor AdblockParamSpecCustomRulesEditor;

struct _AdblockStatusIconPrivate {
	AdblockConfig* config;
	AdblockSubscriptionManager* manager;
};

struct _Block2Data {
	int _ref_count_;
	AdblockStatusIcon* self;
	GtkToggleAction* checkitem;
	GtkToggleAction* hideritem;
	AdblockConfig* config;
	AdblockSubscriptionManager* manager;
};

struct _AdblockSubscriptionManagerPrivate {
	GtkTreeView* treeview;
	GtkListStore* liststore;
	AdblockConfig* config;
	gchar* description;
};

struct _Block3Data {
	int _ref_count_;
	AdblockSubscriptionManager* self;
	GtkDialog* dialog;
	GtkEntry* entry;
};

struct _AdblockParamSpecSubscriptionManager {
	GParamSpec parent_instance;
};

struct _AdblockCustomRulesEditor {
	GTypeInstance parent_instance;
	volatile int ref_count;
	AdblockCustomRulesEditorPrivate * priv;
};

struct _AdblockCustomRulesEditorClass {
	GTypeClass parent_class;
	void (*finalize) (AdblockCustomRulesEditor *self);
};

struct _AdblockCustomRulesEditorPrivate {
	GtkDialog* dialog;
	AdblockSubscription* custom;
	gchar* _rule;
};

struct _AdblockParamSpecCustomRulesEditor {
	GParamSpec parent_instance;
};


static gpointer adblock_status_icon_parent_class = NULL;
static gpointer adblock_subscription_manager_parent_class = NULL;
static gpointer adblock_custom_rules_editor_parent_class = NULL;

#define ADBLOCK_STATUS_ICON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ADBLOCK_TYPE_STATUS_ICON, AdblockStatusIconPrivate))
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda9_ (Block2Data* _data2_);
static void ___lambda9__gtk_action_activate (GtkAction* _sender, gpointer self);
static void __lambda10_ (Block2Data* _data2_);
static void ___lambda10__gtk_toggle_action_toggled (GtkToggleAction* _sender, gpointer self);
static void __lambda11_ (Block2Data* _data2_);
static void ___lambda11__gtk_toggle_action_toggled (GtkToggleAction* _sender, gpointer self);
static void adblock_status_icon_set_status (AdblockStatusIcon* self, const gchar* status);
static void adblock_status_icon_finalize (GObject * obj);
#define ADBLOCK_SUBSCRIPTION_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ADBLOCK_TYPE_SUBSCRIPTION_MANAGER, AdblockSubscriptionManagerPrivate))
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda4_ (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void ___lambda4__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void __lambda5_ (AdblockSubscriptionManager* self, const gchar* path);
static void ___lambda5__gtk_cell_renderer_toggle_toggled (GtkCellRendererToggle* _sender, const gchar* path, gpointer self);
static void __lambda6_ (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void ___lambda6__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void adblock_subscription_manager_on_render_button (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void _adblock_subscription_manager_on_render_button_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static gboolean _adblock_subscription_manager_button_released_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static void __lambda7_ (Block3Data* _data3_);
static void ___lambda7__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void __lambda8_ (Block3Data* _data3_, gint response);
static void ___lambda8__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void adblock_subscription_manager_finalize (AdblockSubscriptionManager * obj);
gpointer adblock_custom_rules_editor_ref (gpointer instance);
void adblock_custom_rules_editor_unref (gpointer instance);
GParamSpec* adblock_param_spec_custom_rules_editor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void adblock_value_set_custom_rules_editor (GValue* value, gpointer v_object);
void adblock_value_take_custom_rules_editor (GValue* value, gpointer v_object);
gpointer adblock_value_get_custom_rules_editor (const GValue* value);
GType adblock_custom_rules_editor_get_type (void) G_GNUC_CONST;
#define ADBLOCK_CUSTOM_RULES_EDITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, AdblockCustomRulesEditorPrivate))
AdblockCustomRulesEditor* adblock_custom_rules_editor_new (AdblockSubscription* custom);
AdblockCustomRulesEditor* adblock_custom_rules_editor_construct (GType object_type, AdblockSubscription* custom);
void adblock_custom_rules_editor_set_uri (AdblockCustomRulesEditor* self, const gchar* uri);
void adblock_custom_rules_editor_set_rule (AdblockCustomRulesEditor* self, const gchar* value);
void adblock_custom_rules_editor_show (AdblockCustomRulesEditor* self);
const gchar* adblock_custom_rules_editor_get_rule (AdblockCustomRulesEditor* self);
static void adblock_custom_rules_editor_finalize (AdblockCustomRulesEditor * obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return self ? g_object_ref (self) : NULL;
#line 162 "widgets.c"
}


static gpointer _adblock_subscription_manager_ref0 (gpointer self) {
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return self ? adblock_subscription_manager_ref (self) : NULL;
#line 169 "widgets.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return _data2_;
#line 178 "widgets.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 187 "widgets.c"
		AdblockStatusIcon* self;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		self = _data2_->self;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_data2_->hideritem);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_data2_->checkitem);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_data2_->config);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_adblock_subscription_manager_unref0 (_data2_->manager);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (self);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_slice_free (Block2Data, _data2_);
#line 203 "widgets.c"
	}
}


static void __lambda9_ (Block2Data* _data2_) {
	AdblockStatusIcon* self;
	AdblockSubscriptionManager* _tmp0_;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = _data2_->self;
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = _data2_->manager;
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_subscription_manager_add_subscription (_tmp0_, NULL);
#line 217 "widgets.c"
}


static void ___lambda9__gtk_action_activate (GtkAction* _sender, gpointer self) {
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda9_ (self);
#line 224 "widgets.c"
}


static void __lambda10_ (Block2Data* _data2_) {
	AdblockStatusIcon* self;
	AdblockConfig* _tmp0_;
	GtkToggleAction* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	AdblockState _tmp4_ = 0;
	AdblockConfig* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = _data2_->self;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = _data2_->config;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = _data2_->checkitem;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = gtk_toggle_action_get_active (_tmp1_);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = _tmp2_;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_config_set_enabled (_tmp0_, !_tmp3_);
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = _data2_->config;
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = adblock_config_get_enabled (_tmp5_);
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = _tmp6_;
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp7_) {
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp4_ = ADBLOCK_STATE_ENABLED;
#line 260 "widgets.c"
	} else {
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp4_ = ADBLOCK_STATE_DISABLED;
#line 264 "widgets.c"
	}
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_status_icon_set_state (self, _tmp4_);
#line 268 "widgets.c"
}


static void ___lambda10__gtk_toggle_action_toggled (GtkToggleAction* _sender, gpointer self) {
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda10_ (self);
#line 275 "widgets.c"
}


static void __lambda11_ (Block2Data* _data2_) {
	AdblockStatusIcon* self;
	GtkToggleAction* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = _data2_->self;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = _data2_->hideritem;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = gtk_toggle_action_get_active (_tmp0_);
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = _tmp1_;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->debug_element_toggled = _tmp2_;
#line 294 "widgets.c"
}


static void ___lambda11__gtk_toggle_action_toggled (GtkToggleAction* _sender, gpointer self) {
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda11_ (self);
#line 301 "widgets.c"
}


AdblockStatusIcon* adblock_status_icon_construct (GType object_type, AdblockConfig* config, AdblockSubscriptionManager* manager) {
	AdblockStatusIcon * self = NULL;
	Block2Data* _data2_;
	AdblockConfig* _tmp0_;
	AdblockConfig* _tmp1_;
	AdblockSubscriptionManager* _tmp2_;
	AdblockSubscriptionManager* _tmp3_;
	AdblockConfig* _tmp4_;
	AdblockConfig* _tmp5_;
	AdblockSubscriptionManager* _tmp6_;
	AdblockSubscriptionManager* _tmp7_;
	MidoriContextAction* item = NULL;
	MidoriContextAction* _tmp8_;
	MidoriContextAction* _tmp9_;
	MidoriContextAction* _tmp10_;
	GtkToggleAction* _tmp11_;
	GtkToggleAction* _tmp12_;
	AdblockConfig* _tmp13_;
	gboolean _tmp14_;
	gboolean _tmp15_;
	GtkToggleAction* _tmp16_;
	GtkToggleAction* _tmp17_;
	GtkToggleAction* _tmp18_;
	GtkToggleAction* _tmp19_;
	gboolean _tmp20_;
	GtkToggleAction* _tmp21_;
	GtkToggleAction* _tmp22_;
	const gchar* _tmp23_ = NULL;
	AdblockConfig* _tmp24_;
	gboolean _tmp25_;
	gboolean _tmp26_;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->_ref_count_ = 1;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = config;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (_data2_->config);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->config = _tmp1_;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = manager;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = _adblock_subscription_manager_ref0 (_tmp2_);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_adblock_subscription_manager_unref0 (_data2_->manager);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->manager = _tmp3_;
#line 23 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = (AdblockStatusIcon*) g_object_new (object_type, "name", "AdblockStatusMenu", NULL);
#line 23 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->self = g_object_ref (self);
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = _data2_->config;
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->config);
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->config = _tmp5_;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = _data2_->manager;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = _adblock_subscription_manager_ref0 (_tmp6_);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_adblock_subscription_manager_unref0 (self->priv->manager);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->manager = _tmp7_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->debug_element_toggled = FALSE;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp8_ = midori_context_action_new ("Preferences", _ ("Preferences"), NULL, GTK_STOCK_PREFERENCES);
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	item = _tmp8_;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp9_ = item;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect_data ((GtkAction*) _tmp9_, "activate", (GCallback) ___lambda9__gtk_action_activate, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp10_ = item;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	midori_context_action_add ((MidoriContextAction*) self, (GtkAction*) _tmp10_);
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	midori_context_action_add ((MidoriContextAction*) self, NULL);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp11_ = gtk_toggle_action_new ("Disable", _ ("Disable"), NULL, NULL);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->checkitem = _tmp11_;
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp12_ = _data2_->checkitem;
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp13_ = _data2_->config;
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp14_ = adblock_config_get_enabled (_tmp13_);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp15_ = _tmp14_;
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_toggle_action_set_active (_tmp12_, !_tmp15_);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp16_ = _data2_->checkitem;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect_data (_tmp16_, "toggled", (GCallback) ___lambda10__gtk_toggle_action_toggled, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp17_ = _data2_->checkitem;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	midori_context_action_add ((MidoriContextAction*) self, (GtkAction*) _tmp17_);
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp18_ = gtk_toggle_action_new ("HiddenElements", _ ("Display hidden elements"), NULL, NULL);
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_->hideritem = _tmp18_;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp19_ = _data2_->hideritem;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp20_ = self->debug_element_toggled;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_toggle_action_set_active (_tmp19_, _tmp20_);
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp21_ = _data2_->hideritem;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect_data (_tmp21_, "toggled", (GCallback) ___lambda11__gtk_toggle_action_toggled, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp22_ = _data2_->hideritem;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	midori_context_action_add ((MidoriContextAction*) self, (GtkAction*) _tmp22_);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp24_ = _data2_->config;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp25_ = adblock_config_get_enabled (_tmp24_);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp26_ = _tmp25_;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp26_) {
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp23_ = "enabled";
#line 446 "widgets.c"
	} else {
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp23_ = "disabled";
#line 450 "widgets.c"
	}
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_status_icon_set_status (self, _tmp23_);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (item);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	block2_data_unref (_data2_);
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data2_ = NULL;
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return self;
#line 462 "widgets.c"
}


AdblockStatusIcon* adblock_status_icon_new (AdblockConfig* config, AdblockSubscriptionManager* manager) {
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return adblock_status_icon_construct (ADBLOCK_TYPE_STATUS_ICON, config, manager);
#line 469 "widgets.c"
}


static void adblock_status_icon_set_status (AdblockStatusIcon* self, const gchar* status) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GThemedIcon* _tmp3_;
	GThemedIcon* _tmp4_;
#line 56 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 56 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (status != NULL);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = status;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = g_strdup_printf ("adblock-%s", _tmp0_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = _tmp1_;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = (GThemedIcon*) g_themed_icon_new (_tmp2_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = _tmp3_;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_action_set_gicon ((GtkAction*) self, (GIcon*) _tmp4_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (_tmp4_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (_tmp2_);
#line 499 "widgets.c"
}


void adblock_status_icon_set_state (AdblockStatusIcon* self, AdblockState state) {
	AdblockState _tmp0_;
	AdblockState _tmp1_;
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 61 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = state;
#line 61 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->state = _tmp0_;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = self->state;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp1_ == ADBLOCK_STATE_BLOCKED) {
#line 64 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_status_icon_set_status (self, "blocked");
#line 65 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		gtk_action_set_tooltip ((GtkAction*) self, _ ("Blocking"));
#line 520 "widgets.c"
	} else {
		AdblockState _tmp2_;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp2_ = self->state;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		if (_tmp2_ == ADBLOCK_STATE_ENABLED) {
#line 67 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			adblock_status_icon_set_status (self, "enabled");
#line 68 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			gtk_action_set_tooltip ((GtkAction*) self, _ ("Enabled"));
#line 531 "widgets.c"
		} else {
			AdblockState _tmp3_;
#line 69 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp3_ = self->state;
#line 69 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (_tmp3_ == ADBLOCK_STATE_DISABLED) {
#line 70 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				adblock_status_icon_set_status (self, "disabled");
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				gtk_action_set_tooltip ((GtkAction*) self, _ ("Disabled"));
#line 542 "widgets.c"
			} else {
#line 73 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				g_assert_not_reached ();
#line 546 "widgets.c"
			}
		}
	}
}


static void adblock_status_icon_class_init (AdblockStatusIconClass * klass) {
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_status_icon_parent_class = g_type_class_peek_parent (klass);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_type_class_add_private (klass, sizeof (AdblockStatusIconPrivate));
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	G_OBJECT_CLASS (klass)->finalize = adblock_status_icon_finalize;
#line 560 "widgets.c"
}


static void adblock_status_icon_instance_init (AdblockStatusIcon * self) {
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv = ADBLOCK_STATUS_ICON_GET_PRIVATE (self);
#line 567 "widgets.c"
}


static void adblock_status_icon_finalize (GObject * obj) {
	AdblockStatusIcon * self;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ADBLOCK_TYPE_STATUS_ICON, AdblockStatusIcon);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->config);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_adblock_subscription_manager_unref0 (self->priv->manager);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	G_OBJECT_CLASS (adblock_status_icon_parent_class)->finalize (obj);
#line 581 "widgets.c"
}


GType adblock_status_icon_get_type (void) {
	static volatile gsize adblock_status_icon_type_id__volatile = 0;
	if (g_once_init_enter (&adblock_status_icon_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AdblockStatusIconClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adblock_status_icon_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdblockStatusIcon), 0, (GInstanceInitFunc) adblock_status_icon_instance_init, NULL };
		GType adblock_status_icon_type_id;
		adblock_status_icon_type_id = g_type_register_static (MIDORI_TYPE_CONTEXT_ACTION, "AdblockStatusIcon", &g_define_type_info, 0);
		g_once_init_leave (&adblock_status_icon_type_id__volatile, adblock_status_icon_type_id);
	}
	return adblock_status_icon_type_id__volatile;
}


AdblockSubscriptionManager* adblock_subscription_manager_construct (GType object_type, AdblockConfig* config) {
	AdblockSubscriptionManager* self = NULL;
	AdblockConfig* _tmp0_;
	AdblockConfig* _tmp1_;
	GtkListStore* _tmp2_;
	GtkLabel* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = (AdblockSubscriptionManager*) g_type_create_instance (object_type);
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = config;
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->config);
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->config = _tmp1_;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = gtk_list_store_new (1, ADBLOCK_TYPE_SUBSCRIPTION);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->liststore);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->liststore = _tmp2_;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = (GtkLabel*) gtk_label_new (NULL);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp3_);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->description_label);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->description_label = _tmp3_;
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = g_strdup (_ ("Type the address of a preconfigured filter list in the text entry and " \
"hit Enter.\n"));
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (self->priv->description);
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->description = _tmp4_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = self->priv->description;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = g_strdup_printf ("You can find more lists by visiting following sites:\n %s, %s\n", "<a href=\"http://adblockplus.org/en/subscriptions\">adblockplus.org/en" \
"/subscriptions</a>", "<a href=\"http://easylist.adblockplus.org/\">easylist.adblockplus.org<" \
"/a>");
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = _tmp6_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp8_ = g_strconcat (_tmp5_, _ (_tmp7_), NULL);
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (self->priv->description);
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->description = _tmp8_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (_tmp7_);
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return self;
#line 656 "widgets.c"
}


AdblockSubscriptionManager* adblock_subscription_manager_new (AdblockConfig* config) {
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return adblock_subscription_manager_construct (ADBLOCK_TYPE_SUBSCRIPTION_MANAGER, config);
#line 663 "widgets.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return _data3_;
#line 672 "widgets.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 681 "widgets.c"
		AdblockSubscriptionManager* self;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		self = _data3_->self;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_data3_->entry);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_data3_->dialog);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_adblock_subscription_manager_unref0 (self);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_slice_free (Block3Data, _data3_);
#line 693 "widgets.c"
	}
}


static void __lambda4_ (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	AdblockSubscription* sub = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkCellRenderer* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (column != NULL);
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (renderer != NULL);
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (model != NULL);
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (iter != NULL);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->liststore;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = *iter;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, 0, &sub, -1);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = renderer;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = adblock_subscription_get_active (sub);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = _tmp3_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = adblock_subscription_get_mutable (sub);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = _tmp5_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_set ((GObject*) _tmp2_, "active", _tmp4_, "sensitive", _tmp6_, NULL);
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (sub);
#line 735 "widgets.c"
}


static void ___lambda4__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda4_ ((AdblockSubscriptionManager*) self, cell_layout, cell, tree_model, iter);
#line 742 "widgets.c"
}


static void __lambda5_ (AdblockSubscriptionManager* self, const gchar* path) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	const gchar* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (path != NULL);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->liststore;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = path;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = gtk_tree_model_get_iter_from_string ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	iter = _tmp2_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp3_) {
#line 764 "widgets.c"
		AdblockSubscription* sub = NULL;
		GtkListStore* _tmp4_;
		GtkTreeIter _tmp5_;
		AdblockSubscription* _tmp6_;
		AdblockSubscription* _tmp7_;
		gboolean _tmp8_;
		gboolean _tmp9_;
#line 139 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp4_ = self->priv->liststore;
#line 139 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp5_ = iter;
#line 139 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, 0, &sub, -1);
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp6_ = sub;
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp7_ = sub;
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp8_ = adblock_subscription_get_active (_tmp7_);
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp9_ = _tmp8_;
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_subscription_set_active (_tmp6_, !_tmp9_);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (sub);
#line 790 "widgets.c"
	}
}


static void ___lambda5__gtk_cell_renderer_toggle_toggled (GtkCellRendererToggle* _sender, const gchar* path, gpointer self) {
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda5_ ((AdblockSubscriptionManager*) self, path);
#line 798 "widgets.c"
}


static void __lambda6_ (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	AdblockSubscription* sub = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* status = NULL;
	gchar* _tmp2_;
	AdblockSubscription* _tmp24_;
	gboolean _tmp25_;
	gboolean _tmp26_;
	const gchar* _tmp28_ = NULL;
	AdblockSubscription* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	GtkCellRenderer* _tmp35_;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (column != NULL);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (renderer != NULL);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (model != NULL);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (iter != NULL);
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->liststore;
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = *iter;
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, 0, &sub, -1);
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = g_strdup ("");
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	status = _tmp2_;
#line 837 "widgets.c"
	{
		AdblockSubscription* _feature_list = NULL;
		AdblockSubscription* _tmp3_;
		AdblockSubscription* _tmp4_;
		guint _feature_size = 0U;
		AdblockSubscription* _tmp5_;
		guint _tmp6_;
		guint _tmp7_;
		gint _feature_index = 0;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp3_ = sub;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_feature_list = _tmp4_;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp5_ = _feature_list;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp6_ = adblock_subscription_get_size (_tmp5_);
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp7_ = _tmp6_;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_feature_size = _tmp7_;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_feature_index = -1;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		while (TRUE) {
#line 865 "widgets.c"
			gint _tmp8_;
			gint _tmp9_;
			guint _tmp10_;
			AdblockFeature* feature = NULL;
			AdblockSubscription* _tmp11_;
			gint _tmp12_;
			AdblockFeature* _tmp13_;
			AdblockUpdater* updater = NULL;
			AdblockFeature* _tmp14_;
			AdblockUpdater* _tmp15_;
			AdblockUpdater* _tmp16_;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp8_ = _feature_index;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_feature_index = _tmp8_ + 1;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp9_ = _feature_index;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp10_ = _feature_size;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (!(((guint) _tmp9_) < _tmp10_)) {
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				break;
#line 889 "widgets.c"
			}
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp11_ = _feature_list;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp12_ = _feature_index;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp13_ = adblock_subscription_get (_tmp11_, (guint) _tmp12_);
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			feature = _tmp13_;
#line 155 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp14_ = feature;
#line 155 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, ADBLOCK_TYPE_UPDATER) ? ((AdblockUpdater*) _tmp14_) : NULL);
#line 155 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			updater = _tmp15_;
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp16_ = updater;
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (_tmp16_ != NULL) {
#line 909 "widgets.c"
				AdblockUpdater* _tmp17_;
				GDateTime* _tmp18_;
				GDateTime* _tmp19_;
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp17_ = updater;
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp18_ = adblock_updater_get_last_updated (_tmp17_);
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp19_ = _tmp18_;
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				if (_tmp19_ != NULL) {
#line 921 "widgets.c"
					AdblockUpdater* _tmp20_;
					GDateTime* _tmp21_;
					GDateTime* _tmp22_;
					gchar* _tmp23_;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp20_ = updater;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp21_ = adblock_updater_get_last_updated (_tmp20_);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp22_ = _tmp21_;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp23_ = g_date_time_format (_tmp22_, _ ("Last update: %x %X"));
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_g_free0 (status);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					status = _tmp23_;
#line 938 "widgets.c"
				}
			}
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_g_object_unref0 (updater);
#line 943 "widgets.c"
		}
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_feature_list);
#line 947 "widgets.c"
	}
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp24_ = sub;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp25_ = adblock_subscription_get_valid (_tmp24_);
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp26_ = _tmp25_;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (!_tmp26_) {
#line 957 "widgets.c"
		gchar* _tmp27_;
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp27_ = g_strdup (_ ("File incomplete - broken download?"));
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_free0 (status);
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		status = _tmp27_;
#line 965 "widgets.c"
	}
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp29_ = sub;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp30_ = adblock_subscription_get_title (_tmp29_);
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp31_ = _tmp30_;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp28_ = _tmp31_;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp28_ == NULL) {
#line 977 "widgets.c"
		AdblockSubscription* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp32_ = sub;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp33_ = adblock_subscription_get_uri (_tmp32_);
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp34_ = _tmp33_;
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp28_ = _tmp34_;
#line 989 "widgets.c"
	}
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp35_ = renderer;
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp36_ = status;
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp37_ = g_markup_printf_escaped ("<b>%s</b>\n%s", _tmp28_, _tmp36_);
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp38_ = _tmp37_;
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_set ((GObject*) _tmp35_, "markup", _tmp38_, NULL);
#line 163 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (_tmp38_);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (status);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (sub);
#line 1007 "widgets.c"
}


static void ___lambda6__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda6_ ((AdblockSubscriptionManager*) self, cell_layout, cell, tree_model, iter);
#line 1014 "widgets.c"
}


static void _adblock_subscription_manager_on_render_button_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_subscription_manager_on_render_button ((AdblockSubscriptionManager*) self, cell_layout, cell, tree_model, iter);
#line 1021 "widgets.c"
}


static gboolean _adblock_subscription_manager_button_released_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = adblock_subscription_manager_button_released ((AdblockSubscriptionManager*) self, event);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return result;
#line 1030 "widgets.c"
}


static void __lambda7_ (Block3Data* _data3_) {
	AdblockSubscriptionManager* self;
	gchar* parsed_uri = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	GtkEntry* _tmp18_;
	GError * _inner_error_ = NULL;
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = _data3_->self;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = _data3_->entry;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = _tmp1_;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = adblock_parse_subscription_uri (_tmp2_);
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	parsed_uri = _tmp3_;
#line 188 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = parsed_uri;
#line 188 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp4_ != NULL) {
#line 1060 "widgets.c"
		AdblockSubscription* sub = NULL;
		const gchar* _tmp5_;
		AdblockSubscription* _tmp6_;
		AdblockConfig* _tmp7_;
		AdblockSubscription* _tmp8_;
		gboolean _tmp9_;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp5_ = parsed_uri;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp6_ = adblock_subscription_new (_tmp5_);
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		sub = _tmp6_;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp7_ = self->priv->config;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp8_ = sub;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp9_ = adblock_config_add (_tmp7_, _tmp8_);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		if (_tmp9_) {
#line 1081 "widgets.c"
			GtkListStore* _tmp10_;
			AdblockSubscription* _tmp11_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp10_ = self->priv->liststore;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp11_ = sub;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			gtk_list_store_insert_with_values (_tmp10_, NULL, 0, 0, _tmp11_, -1);
#line 1090 "widgets.c"
			{
				AdblockSubscription* _tmp12_;
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp12_ = sub;
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				adblock_subscription_parse (_tmp12_, &_inner_error_);
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1099 "widgets.c"
					goto __catch19_g_error;
				}
			}
			goto __finally19;
			__catch19_g_error:
			{
				GError* _error_ = NULL;
				AdblockSubscription* _tmp13_;
				const gchar* _tmp14_;
				const gchar* _tmp15_;
				GError* _tmp16_;
				const gchar* _tmp17_;
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_error_ = _inner_error_;
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_inner_error_ = NULL;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp13_ = sub;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp14_ = adblock_subscription_get_uri (_tmp13_);
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp15_ = _tmp14_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp16_ = _error_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp17_ = _tmp16_->message;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				g_warning ("widgets.vala:195: Error parsing %s: %s", _tmp15_, _tmp17_);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_g_error_free0 (_error_);
#line 1130 "widgets.c"
			}
			__finally19:
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_g_object_unref0 (sub);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_g_free0 (parsed_uri);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				g_clear_error (&_inner_error_);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				return;
#line 1145 "widgets.c"
			}
		}
#line 188 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (sub);
#line 1150 "widgets.c"
	}
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp18_ = _data3_->entry;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_entry_set_text (_tmp18_, "");
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (parsed_uri);
#line 1158 "widgets.c"
}


static void ___lambda7__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda7_ (self);
#line 1165 "widgets.c"
}


static void __lambda8_ (Block3Data* _data3_, gint response) {
	AdblockSubscriptionManager* self;
	GtkDialog* _tmp0_;
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = _data3_->self;
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = _data3_->dialog;
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_object_destroy ((GtkObject*) _tmp0_);
#line 1178 "widgets.c"
}


static void ___lambda8__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	__lambda8_ (self, response_id);
#line 1185 "widgets.c"
}


void adblock_subscription_manager_add_subscription (AdblockSubscriptionManager* self, const gchar* uri) {
	Block3Data* _data3_;
	GtkDialog* _tmp0_;
	GtkDialog* _tmp1_;
	GtkDialog* _tmp2_;
	GtkHBox* hbox = NULL;
	GtkHBox* _tmp3_;
	GtkDialog* _tmp4_;
	GtkWidget* _tmp5_;
	GtkHBox* _tmp6_;
	GtkVBox* vbox = NULL;
	GtkVBox* _tmp7_;
	GtkHBox* _tmp8_;
	GtkVBox* _tmp9_;
	GtkLabel* _tmp10_;
	const gchar* _tmp11_;
	GtkLabel* _tmp12_;
	GtkVBox* _tmp13_;
	GtkLabel* _tmp14_;
	GtkEntry* _tmp15_;
	const gchar* _tmp16_;
	GtkVBox* _tmp19_;
	GtkEntry* _tmp20_;
	GtkListStore* _tmp21_;
	GtkListStore* _tmp22_;
	GtkTreeView* _tmp23_;
	GtkTreeView* _tmp24_;
	GtkTreeViewColumn* column = NULL;
	GtkTreeViewColumn* _tmp25_;
	GtkCellRendererToggle* renderer_toggle = NULL;
	GtkCellRendererToggle* _tmp26_;
	GtkTreeViewColumn* _tmp27_;
	GtkCellRendererToggle* _tmp28_;
	GtkTreeViewColumn* _tmp29_;
	GtkCellRendererToggle* _tmp30_;
	GtkCellRendererToggle* _tmp31_;
	GtkTreeView* _tmp32_;
	GtkTreeViewColumn* _tmp33_;
	GtkTreeViewColumn* _tmp34_;
	GtkCellRendererText* renderer_text = NULL;
	GtkCellRendererText* _tmp35_;
	GtkTreeViewColumn* _tmp36_;
	GtkCellRendererText* _tmp37_;
	GtkCellRendererText* _tmp38_;
	GtkTreeViewColumn* _tmp39_;
	GtkCellRendererText* _tmp40_;
	GtkTreeView* _tmp41_;
	GtkTreeViewColumn* _tmp42_;
	GtkTreeViewColumn* _tmp43_;
	GtkCellRendererPixbuf* renderer_button = NULL;
	GtkCellRendererPixbuf* _tmp44_;
	GtkTreeViewColumn* _tmp45_;
	GtkCellRendererPixbuf* _tmp46_;
	GtkTreeViewColumn* _tmp47_;
	GtkCellRendererPixbuf* _tmp48_;
	GtkTreeView* _tmp49_;
	GtkTreeViewColumn* _tmp50_;
	GtkScrolledWindow* scrolled = NULL;
	GtkScrolledWindow* _tmp51_;
	GtkScrolledWindow* _tmp52_;
	GtkScrolledWindow* _tmp53_;
	GtkTreeView* _tmp54_;
	GtkVBox* _tmp55_;
	GtkScrolledWindow* _tmp56_;
	gint height = 0;
	GtkTreeView* _tmp57_;
	PangoLayout* _tmp58_;
	PangoLayout* _tmp59_;
	gint _tmp60_ = 0;
	GtkScrolledWindow* _tmp61_;
	gint _tmp62_;
	GtkTreeView* _tmp76_;
	GtkEntry* _tmp77_;
	GtkDialog* _tmp78_;
	GtkWidget* _tmp79_;
	GtkDialog* _tmp80_;
	GtkDialog* _tmp81_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_->_ref_count_ = 1;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_->self = adblock_subscription_manager_ref (self);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = (GtkDialog*) gtk_dialog_new_with_buttons (_ ("Configure Advertisement filters"), NULL, GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_HELP, GTK_RESPONSE_HELP, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp0_);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_->dialog = _tmp0_;
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = _data3_->dialog;
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_window_set_icon_name ((GtkWindow*) _tmp1_, GTK_STOCK_PROPERTIES);
#line 108 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = _data3_->dialog;
#line 108 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_dialog_set_response_sensitive (_tmp2_, (gint) GTK_RESPONSE_HELP, FALSE);
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp3_);
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	hbox = _tmp3_;
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = _data3_->dialog;
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = gtk_dialog_get_content_area (_tmp4_);
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = hbox;
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp5_) : NULL, (GtkWidget*) _tmp6_, TRUE, TRUE, (guint) 12);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = (GtkVBox*) gtk_vbox_new (FALSE, 0);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp7_);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	vbox = _tmp7_;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp8_ = hbox;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp9_ = vbox;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp8_, (GtkWidget*) _tmp9_, TRUE, TRUE, (guint) 4);
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp10_ = self->description_label;
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp11_ = self->priv->description;
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_label_set_markup (_tmp10_, _tmp11_);
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp12_ = self->description_label;
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_label_set_line_wrap (_tmp12_, TRUE);
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp13_ = vbox;
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp14_ = self->description_label;
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp13_, (GtkWidget*) _tmp14_, FALSE, FALSE, (guint) 4);
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp15_ = (GtkEntry*) gtk_entry_new ();
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp15_);
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_->entry = _tmp15_;
#line 119 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp16_ = uri;
#line 119 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp16_ != NULL) {
#line 1340 "widgets.c"
		GtkEntry* _tmp17_;
		const gchar* _tmp18_;
#line 120 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp17_ = _data3_->entry;
#line 120 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp18_ = uri;
#line 120 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		gtk_entry_set_text (_tmp17_, _tmp18_);
#line 1349 "widgets.c"
	}
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp19_ = vbox;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp20_ = _data3_->entry;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp19_, (GtkWidget*) _tmp20_, FALSE, FALSE, (guint) 4);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp21_ = gtk_list_store_new (1, ADBLOCK_TYPE_SUBSCRIPTION);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->liststore);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->liststore = _tmp21_;
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp22_ = self->priv->liststore;
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp23_ = (GtkTreeView*) gtk_tree_view_new_with_model ((GtkTreeModel*) _tmp22_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp23_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->treeview);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->treeview = _tmp23_;
#line 125 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp24_ = self->priv->treeview;
#line 125 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_view_set_headers_visible (_tmp24_, FALSE);
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp25_ = gtk_tree_view_column_new ();
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp25_);
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	column = _tmp25_;
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp26_ = (GtkCellRendererToggle*) gtk_cell_renderer_toggle_new ();
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp26_);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	renderer_toggle = _tmp26_;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp27_ = column;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp28_ = renderer_toggle;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp27_, (GtkCellRenderer*) _tmp28_, FALSE);
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp29_ = column;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp30_ = renderer_toggle;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp29_, (GtkCellRenderer*) _tmp30_, ___lambda4__gtk_cell_layout_data_func, adblock_subscription_manager_ref (self), adblock_subscription_manager_unref);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp31_ = renderer_toggle;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect (_tmp31_, "toggled", (GCallback) ___lambda5__gtk_cell_renderer_toggle_toggled, self);
#line 143 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp32_ = self->priv->treeview;
#line 143 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp33_ = column;
#line 143 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_view_append_column (_tmp32_, _tmp33_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp34_ = gtk_tree_view_column_new ();
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp34_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (column);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	column = _tmp34_;
#line 146 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp35_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 146 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp35_);
#line 146 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	renderer_text = _tmp35_;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp36_ = column;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp37_ = renderer_text;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp36_, (GtkCellRenderer*) _tmp37_, FALSE);
#line 148 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp38_ = renderer_text;
#line 148 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_set ((GObject*) _tmp38_, "editable", TRUE, NULL);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp39_ = column;
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp40_ = renderer_text;
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp39_, (GtkCellRenderer*) _tmp40_, ___lambda6__gtk_cell_layout_data_func, adblock_subscription_manager_ref (self), adblock_subscription_manager_unref);
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp41_ = self->priv->treeview;
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp42_ = column;
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_view_append_column (_tmp41_, _tmp42_);
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp43_ = gtk_tree_view_column_new ();
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp43_);
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (column);
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	column = _tmp43_;
#line 169 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp44_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 169 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp44_);
#line 169 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	renderer_button = _tmp44_;
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp45_ = column;
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp46_ = renderer_button;
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp45_, (GtkCellRenderer*) _tmp46_, FALSE);
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp47_ = column;
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp48_ = renderer_button;
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp47_, (GtkCellRenderer*) _tmp48_, _adblock_subscription_manager_on_render_button_gtk_cell_layout_data_func, adblock_subscription_manager_ref (self), adblock_subscription_manager_unref);
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp49_ = self->priv->treeview;
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp50_ = column;
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_view_append_column (_tmp49_, _tmp50_);
#line 174 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp51_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 174 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp51_);
#line 174 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	scrolled = _tmp51_;
#line 175 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp52_ = scrolled;
#line 175 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_scrolled_window_set_policy (_tmp52_, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp53_ = scrolled;
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp54_ = self->priv->treeview;
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_container_add ((GtkContainer*) _tmp53_, (GtkWidget*) _tmp54_);
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp55_ = vbox;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp56_ = scrolled;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp55_, (GtkWidget*) _tmp56_, TRUE, TRUE, (guint) 0);
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp57_ = self->priv->treeview;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp58_ = gtk_widget_create_pango_layout ((GtkWidget*) _tmp57_, "a\nb");
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp59_ = _tmp58_;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	pango_layout_get_pixel_size (_tmp59_, NULL, &_tmp60_);
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	height = _tmp60_;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (_tmp59_);
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp61_ = scrolled;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp62_ = height;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp61_, -1, _tmp62_ * 5);
#line 1519 "widgets.c"
	{
		AdblockConfig* _sub_list = NULL;
		AdblockConfig* _tmp63_;
		AdblockConfig* _tmp64_;
		guint _sub_size = 0U;
		AdblockConfig* _tmp65_;
		guint _tmp66_;
		guint _tmp67_;
		gint _sub_index = 0;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp63_ = self->priv->config;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp64_ = _g_object_ref0 (_tmp63_);
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_sub_list = _tmp64_;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp65_ = _sub_list;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp66_ = adblock_config_get_size (_tmp65_);
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp67_ = _tmp66_;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_sub_size = _tmp67_;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_sub_index = -1;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		while (TRUE) {
#line 1547 "widgets.c"
			gint _tmp68_;
			gint _tmp69_;
			guint _tmp70_;
			AdblockSubscription* sub = NULL;
			AdblockConfig* _tmp71_;
			gint _tmp72_;
			AdblockSubscription* _tmp73_;
			GtkListStore* _tmp74_;
			AdblockSubscription* _tmp75_;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp68_ = _sub_index;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_sub_index = _tmp68_ + 1;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp69_ = _sub_index;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp70_ = _sub_size;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (!(((guint) _tmp69_) < _tmp70_)) {
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				break;
#line 1569 "widgets.c"
			}
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp71_ = _sub_list;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp72_ = _sub_index;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp73_ = adblock_config_get (_tmp71_, (guint) _tmp72_);
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			sub = _tmp73_;
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp74_ = self->priv->liststore;
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp75_ = sub;
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			gtk_list_store_insert_with_values (_tmp74_, NULL, 0, 0, _tmp75_, -1);
#line 1585 "widgets.c"
		}
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (_sub_list);
#line 1589 "widgets.c"
	}
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp76_ = self->priv->treeview;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect ((GtkWidget*) _tmp76_, "button-release-event", (GCallback) _adblock_subscription_manager_button_released_gtk_widget_button_release_event, self);
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp77_ = _data3_->entry;
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect_data (_tmp77_, "activate", (GCallback) ___lambda7__gtk_entry_activate, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp78_ = _data3_->dialog;
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp79_ = gtk_dialog_get_content_area (_tmp78_);
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_widget_show_all (_tmp79_);
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp80_ = _data3_->dialog;
#line 204 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_connect_data (_tmp80_, "response", (GCallback) ___lambda8__gtk_dialog_response, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp81_ = _data3_->dialog;
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_widget_show ((GtkWidget*) _tmp81_);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (scrolled);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (renderer_button);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (renderer_text);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (renderer_toggle);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (column);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (vbox);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (hbox);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	block3_data_unref (_data3_);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_data3_ = NULL;
#line 1631 "widgets.c"
}


static void adblock_subscription_manager_on_render_button (AdblockSubscriptionManager* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	AdblockSubscription* sub = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	const gchar* _tmp2_ = NULL;
	AdblockSubscription* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	GtkCellRenderer* _tmp6_;
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (column != NULL);
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (renderer != NULL);
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (model != NULL);
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (iter != NULL);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->liststore;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = *iter;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, 0, &sub, -1);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = sub;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = adblock_subscription_get_mutable (_tmp3_);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = _tmp4_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp5_) {
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp2_ = GTK_STOCK_DELETE;
#line 1670 "widgets.c"
	} else {
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp2_ = NULL;
#line 1674 "widgets.c"
	}
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = renderer;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_set ((GObject*) _tmp6_, "stock-id", _tmp2_, "stock-size", GTK_ICON_SIZE_MENU, NULL);
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (sub);
#line 1682 "widgets.c"
}


gboolean adblock_subscription_manager_button_released (AdblockSubscriptionManager* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	GtkTreeView* _tmp0_;
	GdkEventButton _tmp1_;
	gdouble _tmp2_;
	GdkEventButton _tmp3_;
	gdouble _tmp4_;
	GtkTreePath* _tmp5_ = NULL;
	GtkTreeViewColumn* _tmp6_ = NULL;
	gboolean _tmp7_;
	GtkTreeViewColumn* _tmp8_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->treeview;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = *event;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = _tmp1_.x;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = *event;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = _tmp3_.y;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = gtk_tree_view_get_path_at_pos (_tmp0_, (gint) _tmp2_, (gint) _tmp4_, &_tmp5_, &_tmp6_, NULL, NULL);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_gtk_tree_path_free0 (path);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	path = _tmp5_;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (column);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp8_ = _g_object_ref0 (_tmp6_);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	column = _tmp8_;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp7_) {
#line 1727 "widgets.c"
		GtkTreePath* _tmp9_;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_tmp9_ = path;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		if (_tmp9_ != NULL) {
#line 1733 "widgets.c"
			GtkTreeViewColumn* _tmp10_;
			GtkTreeView* _tmp11_;
			GtkTreeViewColumn* _tmp12_;
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp10_ = column;
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp11_ = self->priv->treeview;
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			_tmp12_ = gtk_tree_view_get_column (_tmp11_, 2);
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			if (_tmp10_ == _tmp12_) {
#line 1745 "widgets.c"
				GtkTreeIter iter = {0};
				GtkListStore* _tmp13_;
				GtkTreePath* _tmp14_;
				GtkTreeIter _tmp15_ = {0};
				gboolean _tmp16_;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp13_ = self->priv->liststore;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp14_ = path;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				_tmp16_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp13_, &_tmp15_, _tmp14_);
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				iter = _tmp15_;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
				if (_tmp16_) {
#line 1761 "widgets.c"
					AdblockSubscription* sub = NULL;
					GtkListStore* _tmp17_;
					GtkTreeIter _tmp18_;
					AdblockSubscription* _tmp19_;
					gboolean _tmp20_;
					gboolean _tmp21_;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp17_ = self->priv->liststore;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp18_ = iter;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					gtk_tree_model_get ((GtkTreeModel*) _tmp17_, &_tmp18_, 0, &sub, -1);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp19_ = sub;
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp20_ = adblock_subscription_get_mutable (_tmp19_);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_tmp21_ = _tmp20_;
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					if (_tmp21_) {
#line 1782 "widgets.c"
						AdblockConfig* _tmp22_;
						AdblockSubscription* _tmp23_;
						GtkListStore* _tmp24_;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_tmp22_ = self->priv->config;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_tmp23_ = sub;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						adblock_config_remove (_tmp22_, _tmp23_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_tmp24_ = self->priv->liststore;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						gtk_list_store_remove (_tmp24_, &iter);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						result = TRUE;
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_g_object_unref0 (sub);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_g_object_unref0 (column);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						_gtk_tree_path_free0 (path);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
						return result;
#line 1806 "widgets.c"
					}
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
					_g_object_unref0 (sub);
#line 1810 "widgets.c"
				}
			}
		}
	}
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	result = FALSE;
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (column);
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_gtk_tree_path_free0 (path);
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return result;
#line 1823 "widgets.c"
}


static void adblock_value_subscription_manager_init (GValue* value) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	value->data[0].v_pointer = NULL;
#line 1830 "widgets.c"
}


static void adblock_value_subscription_manager_free_value (GValue* value) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (value->data[0].v_pointer) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_subscription_manager_unref (value->data[0].v_pointer);
#line 1839 "widgets.c"
	}
}


static void adblock_value_subscription_manager_copy_value (const GValue* src_value, GValue* dest_value) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (src_value->data[0].v_pointer) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		dest_value->data[0].v_pointer = adblock_subscription_manager_ref (src_value->data[0].v_pointer);
#line 1849 "widgets.c"
	} else {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1853 "widgets.c"
	}
}


static gpointer adblock_value_subscription_manager_peek_pointer (const GValue* value) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return value->data[0].v_pointer;
#line 1861 "widgets.c"
}


static gchar* adblock_value_subscription_manager_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (collect_values[0].v_pointer) {
#line 1868 "widgets.c"
		AdblockSubscriptionManager * object;
		object = collect_values[0].v_pointer;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		if (object->parent_instance.g_class == NULL) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1875 "widgets.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1879 "widgets.c"
		}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = adblock_subscription_manager_ref (object);
#line 1883 "widgets.c"
	} else {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 1887 "widgets.c"
	}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return NULL;
#line 1891 "widgets.c"
}


static gchar* adblock_value_subscription_manager_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	AdblockSubscriptionManager ** object_p;
	object_p = collect_values[0].v_pointer;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (!object_p) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1902 "widgets.c"
	}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (!value->data[0].v_pointer) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = NULL;
#line 1908 "widgets.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = value->data[0].v_pointer;
#line 1912 "widgets.c"
	} else {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = adblock_subscription_manager_ref (value->data[0].v_pointer);
#line 1916 "widgets.c"
	}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return NULL;
#line 1920 "widgets.c"
}


GParamSpec* adblock_param_spec_subscription_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	AdblockParamSpecSubscriptionManager* spec;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (g_type_is_a (object_type, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER), NULL);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return G_PARAM_SPEC (spec);
#line 1934 "widgets.c"
}


gpointer adblock_value_get_subscription_manager (const GValue* value) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER), NULL);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return value->data[0].v_pointer;
#line 1943 "widgets.c"
}


void adblock_value_set_subscription_manager (GValue* value, gpointer v_object) {
	AdblockSubscriptionManager * old;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	old = value->data[0].v_pointer;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (v_object) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = v_object;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_subscription_manager_ref (value->data[0].v_pointer);
#line 1963 "widgets.c"
	} else {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 1967 "widgets.c"
	}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (old) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_subscription_manager_unref (old);
#line 1973 "widgets.c"
	}
}


void adblock_value_take_subscription_manager (GValue* value, gpointer v_object) {
	AdblockSubscriptionManager * old;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	old = value->data[0].v_pointer;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (v_object) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = v_object;
#line 1992 "widgets.c"
	} else {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 1996 "widgets.c"
	}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (old) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_subscription_manager_unref (old);
#line 2002 "widgets.c"
	}
}


static void adblock_subscription_manager_class_init (AdblockSubscriptionManagerClass * klass) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_subscription_manager_parent_class = g_type_class_peek_parent (klass);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	((AdblockSubscriptionManagerClass *) klass)->finalize = adblock_subscription_manager_finalize;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_type_class_add_private (klass, sizeof (AdblockSubscriptionManagerPrivate));
#line 2014 "widgets.c"
}


static void adblock_subscription_manager_instance_init (AdblockSubscriptionManager * self) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv = ADBLOCK_SUBSCRIPTION_MANAGER_GET_PRIVATE (self);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->ref_count = 1;
#line 2023 "widgets.c"
}


static void adblock_subscription_manager_finalize (AdblockSubscriptionManager * obj) {
	AdblockSubscriptionManager * self;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ADBLOCK_TYPE_SUBSCRIPTION_MANAGER, AdblockSubscriptionManager);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_handlers_destroy (self);
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->treeview);
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->liststore);
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->config);
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->description_label);
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (self->priv->description);
#line 2043 "widgets.c"
}


GType adblock_subscription_manager_get_type (void) {
	static volatile gsize adblock_subscription_manager_type_id__volatile = 0;
	if (g_once_init_enter (&adblock_subscription_manager_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { adblock_value_subscription_manager_init, adblock_value_subscription_manager_free_value, adblock_value_subscription_manager_copy_value, adblock_value_subscription_manager_peek_pointer, "p", adblock_value_subscription_manager_collect_value, "p", adblock_value_subscription_manager_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (AdblockSubscriptionManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adblock_subscription_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdblockSubscriptionManager), 0, (GInstanceInitFunc) adblock_subscription_manager_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType adblock_subscription_manager_type_id;
		adblock_subscription_manager_type_id = g_type_register_fundamental (g_type_fundamental_next (), "AdblockSubscriptionManager", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&adblock_subscription_manager_type_id__volatile, adblock_subscription_manager_type_id);
	}
	return adblock_subscription_manager_type_id__volatile;
}


gpointer adblock_subscription_manager_ref (gpointer instance) {
	AdblockSubscriptionManager * self;
	self = instance;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_atomic_int_inc (&self->ref_count);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return instance;
#line 2068 "widgets.c"
}


void adblock_subscription_manager_unref (gpointer instance) {
	AdblockSubscriptionManager * self;
	self = instance;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		ADBLOCK_SUBSCRIPTION_MANAGER_GET_CLASS (self)->finalize (self);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2081 "widgets.c"
	}
}


AdblockCustomRulesEditor* adblock_custom_rules_editor_construct (GType object_type, AdblockSubscription* custom) {
	AdblockCustomRulesEditor* self = NULL;
	AdblockSubscription* _tmp0_;
	AdblockSubscription* _tmp1_;
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (custom != NULL, NULL);
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = (AdblockCustomRulesEditor*) g_type_create_instance (object_type);
#line 247 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = custom;
#line 247 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 247 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->custom);
#line 247 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->custom = _tmp1_;
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return self;
#line 2104 "widgets.c"
}


AdblockCustomRulesEditor* adblock_custom_rules_editor_new (AdblockSubscription* custom) {
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return adblock_custom_rules_editor_construct (ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, custom);
#line 2111 "widgets.c"
}


void adblock_custom_rules_editor_set_uri (AdblockCustomRulesEditor* self, const gchar* uri) {
	const gchar* _tmp0_;
#line 250 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 250 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (uri != NULL);
#line 251 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = uri;
#line 251 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_custom_rules_editor_set_rule (self, _tmp0_);
#line 2125 "widgets.c"
}


void adblock_custom_rules_editor_show (AdblockCustomRulesEditor* self) {
	GtkDialog* _tmp0_;
	GtkDialog* _tmp1_;
	GtkDialog* _tmp2_;
	GtkHBox* hbox = NULL;
	GtkHBox* _tmp3_;
	GtkSizeGroup* sizegroup = NULL;
	GtkSizeGroup* _tmp4_;
	GtkHBox* _tmp5_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp6_;
	GtkSizeGroup* _tmp7_;
	GtkLabel* _tmp8_;
	GtkHBox* _tmp9_;
	GtkLabel* _tmp10_;
	GtkDialog* _tmp11_;
	GtkWidget* _tmp12_;
	GtkHBox* _tmp13_;
	GtkEntry* entry = NULL;
	GtkEntry* _tmp14_;
	GtkSizeGroup* _tmp15_;
	GtkEntry* _tmp16_;
	GtkEntry* _tmp17_;
	GtkEntry* _tmp18_;
	const gchar* _tmp19_;
	GtkHBox* _tmp20_;
	GtkEntry* _tmp21_;
	GtkDialog* _tmp22_;
	GtkWidget* _tmp23_;
	GtkDialog* _tmp24_;
	GtkDialog* _tmp25_;
	gint _tmp26_;
	GtkEntry* _tmp27_;
	const gchar* _tmp28_;
	GtkDialog* _tmp29_;
	AdblockSubscription* _tmp30_;
	const gchar* _tmp31_;
#line 254 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 255 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = (GtkDialog*) gtk_dialog_new_with_buttons (_ ("Edit rule"), NULL, GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_ADD, GTK_RESPONSE_ACCEPT, NULL);
#line 255 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp0_);
#line 255 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->dialog);
#line 255 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->dialog = _tmp0_;
#line 263 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = self->priv->dialog;
#line 263 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_window_set_icon_name ((GtkWindow*) _tmp1_, GTK_STOCK_ADD);
#line 264 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp2_ = self->priv->dialog;
#line 264 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_window_set_resizable ((GtkWindow*) _tmp2_, FALSE);
#line 266 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp3_ = (GtkHBox*) gtk_hbox_new (FALSE, 8);
#line 266 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp3_);
#line 266 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	hbox = _tmp3_;
#line 267 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp4_ = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
#line 267 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	sizegroup = _tmp4_;
#line 268 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp5_ = hbox;
#line 268 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_container_set_border_width ((GtkContainer*) _tmp5_, (guint) 5);
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new_with_mnemonic (_ ("_Rule:"));
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp6_);
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	label = _tmp6_;
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp7_ = sizegroup;
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp8_ = label;
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_size_group_add_widget (_tmp7_, (GtkWidget*) _tmp8_);
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp9_ = hbox;
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp10_ = label;
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp9_, (GtkWidget*) _tmp10_, FALSE, FALSE, (guint) 0);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp11_ = self->priv->dialog;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp12_ = gtk_dialog_get_content_area (_tmp11_);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp13_ = hbox;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp12_) : NULL, (GtkWidget*) _tmp13_, FALSE, TRUE, (guint) 0);
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp14_ = (GtkEntry*) gtk_entry_new ();
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_object_ref_sink (_tmp14_);
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	entry = _tmp14_;
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp15_ = sizegroup;
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp16_ = entry;
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_size_group_add_widget (_tmp15_, (GtkWidget*) _tmp16_);
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp17_ = entry;
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_entry_set_activates_default (_tmp17_, TRUE);
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp18_ = entry;
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp19_ = self->priv->_rule;
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_entry_set_text (_tmp18_, _tmp19_);
#line 278 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp20_ = hbox;
#line 278 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp21_ = entry;
#line 278 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_box_pack_start ((GtkBox*) _tmp20_, (GtkWidget*) _tmp21_, TRUE, TRUE, (guint) 0);
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp22_ = self->priv->dialog;
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp23_ = gtk_dialog_get_content_area (_tmp22_);
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_widget_show_all (_tmp23_);
#line 282 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp24_ = self->priv->dialog;
#line 282 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_dialog_set_default_response (_tmp24_, (gint) GTK_RESPONSE_ACCEPT);
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp25_ = self->priv->dialog;
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp26_ = gtk_dialog_run (_tmp25_);
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (_tmp26_ != ((gint) GTK_RESPONSE_ACCEPT)) {
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (entry);
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (label);
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (sizegroup);
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		_g_object_unref0 (hbox);
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		return;
#line 2278 "widgets.c"
	}
#line 286 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp27_ = entry;
#line 286 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp28_ = gtk_entry_get_text (_tmp27_);
#line 286 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_custom_rules_editor_set_rule (self, _tmp28_);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp29_ = self->priv->dialog;
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	gtk_object_destroy ((GtkObject*) _tmp29_);
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp30_ = self->priv->custom;
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp31_ = self->priv->_rule;
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_subscription_add_rule (_tmp30_, _tmp31_);
#line 254 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (entry);
#line 254 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (label);
#line 254 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (sizegroup);
#line 254 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (hbox);
#line 2304 "widgets.c"
}


const gchar* adblock_custom_rules_editor_get_rule (AdblockCustomRulesEditor* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = self->priv->_rule;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	result = _tmp0_;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return result;
#line 2319 "widgets.c"
}


void adblock_custom_rules_editor_set_rule (AdblockCustomRulesEditor* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (self != NULL);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp0_ = value;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (self->priv->_rule);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv->_rule = _tmp1_;
#line 2336 "widgets.c"
}


static void adblock_value_custom_rules_editor_init (GValue* value) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	value->data[0].v_pointer = NULL;
#line 2343 "widgets.c"
}


static void adblock_value_custom_rules_editor_free_value (GValue* value) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (value->data[0].v_pointer) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_custom_rules_editor_unref (value->data[0].v_pointer);
#line 2352 "widgets.c"
	}
}


static void adblock_value_custom_rules_editor_copy_value (const GValue* src_value, GValue* dest_value) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (src_value->data[0].v_pointer) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		dest_value->data[0].v_pointer = adblock_custom_rules_editor_ref (src_value->data[0].v_pointer);
#line 2362 "widgets.c"
	} else {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2366 "widgets.c"
	}
}


static gpointer adblock_value_custom_rules_editor_peek_pointer (const GValue* value) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return value->data[0].v_pointer;
#line 2374 "widgets.c"
}


static gchar* adblock_value_custom_rules_editor_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (collect_values[0].v_pointer) {
#line 2381 "widgets.c"
		AdblockCustomRulesEditor * object;
		object = collect_values[0].v_pointer;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		if (object->parent_instance.g_class == NULL) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2388 "widgets.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2392 "widgets.c"
		}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = adblock_custom_rules_editor_ref (object);
#line 2396 "widgets.c"
	} else {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 2400 "widgets.c"
	}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return NULL;
#line 2404 "widgets.c"
}


static gchar* adblock_value_custom_rules_editor_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	AdblockCustomRulesEditor ** object_p;
	object_p = collect_values[0].v_pointer;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (!object_p) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2415 "widgets.c"
	}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (!value->data[0].v_pointer) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = NULL;
#line 2421 "widgets.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = value->data[0].v_pointer;
#line 2425 "widgets.c"
	} else {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		*object_p = adblock_custom_rules_editor_ref (value->data[0].v_pointer);
#line 2429 "widgets.c"
	}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return NULL;
#line 2433 "widgets.c"
}


GParamSpec* adblock_param_spec_custom_rules_editor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	AdblockParamSpecCustomRulesEditor* spec;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (g_type_is_a (object_type, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR), NULL);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return G_PARAM_SPEC (spec);
#line 2447 "widgets.c"
}


gpointer adblock_value_get_custom_rules_editor (const GValue* value) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR), NULL);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return value->data[0].v_pointer;
#line 2456 "widgets.c"
}


void adblock_value_set_custom_rules_editor (GValue* value, gpointer v_object) {
	AdblockCustomRulesEditor * old;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	old = value->data[0].v_pointer;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (v_object) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = v_object;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_custom_rules_editor_ref (value->data[0].v_pointer);
#line 2476 "widgets.c"
	} else {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 2480 "widgets.c"
	}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (old) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_custom_rules_editor_unref (old);
#line 2486 "widgets.c"
	}
}


void adblock_value_take_custom_rules_editor (GValue* value, gpointer v_object) {
	AdblockCustomRulesEditor * old;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	old = value->data[0].v_pointer;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (v_object) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = v_object;
#line 2505 "widgets.c"
	} else {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		value->data[0].v_pointer = NULL;
#line 2509 "widgets.c"
	}
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (old) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		adblock_custom_rules_editor_unref (old);
#line 2515 "widgets.c"
	}
}


static void adblock_custom_rules_editor_class_init (AdblockCustomRulesEditorClass * klass) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	adblock_custom_rules_editor_parent_class = g_type_class_peek_parent (klass);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	((AdblockCustomRulesEditorClass *) klass)->finalize = adblock_custom_rules_editor_finalize;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_type_class_add_private (klass, sizeof (AdblockCustomRulesEditorPrivate));
#line 2527 "widgets.c"
}


static void adblock_custom_rules_editor_instance_init (AdblockCustomRulesEditor * self) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->priv = ADBLOCK_CUSTOM_RULES_EDITOR_GET_PRIVATE (self);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self->ref_count = 1;
#line 2536 "widgets.c"
}


static void adblock_custom_rules_editor_finalize (AdblockCustomRulesEditor * obj) {
	AdblockCustomRulesEditor * self;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ADBLOCK_TYPE_CUSTOM_RULES_EDITOR, AdblockCustomRulesEditor);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_signal_handlers_destroy (self);
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->dialog);
#line 243 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_object_unref0 (self->priv->custom);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	_g_free0 (self->priv->_rule);
#line 2552 "widgets.c"
}


GType adblock_custom_rules_editor_get_type (void) {
	static volatile gsize adblock_custom_rules_editor_type_id__volatile = 0;
	if (g_once_init_enter (&adblock_custom_rules_editor_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { adblock_value_custom_rules_editor_init, adblock_value_custom_rules_editor_free_value, adblock_value_custom_rules_editor_copy_value, adblock_value_custom_rules_editor_peek_pointer, "p", adblock_value_custom_rules_editor_collect_value, "p", adblock_value_custom_rules_editor_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (AdblockCustomRulesEditorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adblock_custom_rules_editor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdblockCustomRulesEditor), 0, (GInstanceInitFunc) adblock_custom_rules_editor_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType adblock_custom_rules_editor_type_id;
		adblock_custom_rules_editor_type_id = g_type_register_fundamental (g_type_fundamental_next (), "AdblockCustomRulesEditor", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&adblock_custom_rules_editor_type_id__volatile, adblock_custom_rules_editor_type_id);
	}
	return adblock_custom_rules_editor_type_id__volatile;
}


gpointer adblock_custom_rules_editor_ref (gpointer instance) {
	AdblockCustomRulesEditor * self;
	self = instance;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	g_atomic_int_inc (&self->ref_count);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	return instance;
#line 2577 "widgets.c"
}


void adblock_custom_rules_editor_unref (gpointer instance) {
	AdblockCustomRulesEditor * self;
	self = instance;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		ADBLOCK_CUSTOM_RULES_EDITOR_GET_CLASS (self)->finalize (self);
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/adblock/widgets.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2590 "widgets.c"
	}
}



